@@ -29,7 +29,7 @@ const MAX_SEARCH_RESULTS = 100
 const SearchProviderInterface = Gio.resources_lookup_data('/org/gnome/shell/ShellSearchProvider2.xml', 0).toArray().toString();
 
 const SearchProvider = new Lang.Class({
-    Name: 'WeatherSearchProvider',
+    Name: 'CharactersSearchProvider',
 
     _init: function(application) {
         this._app = application;
@@ -61,11 +61,9 @@ const SearchProvider = new Lang.Class({
                 let characters = [];
                 try {
                     let result = context.search_finish(res);
-                    for (let index = 0; index < result.len; index++) {
-                        characters.push(Gc.search_result_get(result, index));
-                    }
+                    characters = Util.searchResultToArray(result);
                 } catch (e) {
-                    log("Failed to search by keywords: " + e);
+                    log("Failed to search by keywords: " + e.message);
                 }
                 invocation.return_value(new GLib.Variant('(as)', [characters]));
 
@@ -147,7 +145,7 @@ const SearchProvider = new Lang.Class({
                                   try {
                                       connection.call_finish(result);
                                   } catch(e) {
-                                      log('Failed to launch application: ' + e);
+                                      log('Failed to launch application: ' + e.message);
                                   }
 
                                   this._app.release();
